@@ -1,4 +1,5 @@
-from typing import Iterable
+from datetime import datetime
+from typing import Iterable, Optional
 
 import click
 from arrow import Arrow
@@ -28,14 +29,24 @@ def pretty(publication: Publication):
 
 
 async def list_publications(
-    status: PublicationStatus = None, frm: Arrow = None, to: Arrow = None
+    status: PublicationStatus = None,
+    frm: Optional[datetime] = None,
+    to: Optional[datetime] = None,
 ):
+
+    frm = Arrow.fromdatetime(frm) if frm else None
+    to = Arrow.fromdatetime(to) if to else None
     if status is None:
         publications = await get_all_publications(from_date=frm, to_date=to)
     else:
         publications = await publications_with_status(status, from_date=frm, to_date=to)
 
     if publications:
-        show_publications(list(publications))
+        show_publications(publications)
     else:
-        click.echo(f"No publication found with status: {status.name}")
+        message = (
+            f"No publication found with status: {status.name}"
+            if status is not None
+            else "No publication found"
+        )
+        click.echo(message)
