@@ -5,7 +5,7 @@ from mobilizon_reshare.main.recap import recap
 logger = logging.getLogger(__name__)
 
 
-async def main():
+async def recap_command():
 
     reports = await recap()
     return 0 if reports and reports.successful else 1
