@@ -14,12 +14,12 @@ def html_to_plaintext(content) -> str:
     :return:
     """
     # TODO: support links and quotes
-    soup = BeautifulSoup(content)
+    soup = BeautifulSoup(content, features="html.parser")
     p_list = get_bottom_paragraphs(soup)
     if p_list:
         return "\n".join(" ".join(tag.stripped_strings) for tag in p_list)
-    else:
-        return soup.text
+
+    return soup.text
 
 
 def html_to_markdown(content) -> str:
