@@ -23,7 +23,7 @@ class Event(Model):
     publications: fields.ReverseRelation["Publication"]
 
     def __str__(self):
-        return self.name
+        return str(self.name)
 
     def __repr__(self):
         return f"{self.id} - {self.name}"
